@@ -13,8 +13,8 @@ double **dmatrix(int nrow, int ncol)
   avec=(double *)malloc((unsigned) (nrow*ncol)*sizeof(double));
   amat=(double **)malloc((unsigned) nrow*sizeof(double*));
 #else
-  avec=(double *) Calloc((unsigned) (nrow*ncol), double);
-  amat=(double **) Calloc((unsigned) nrow,double*);   
+  avec=(double *) calloc((unsigned) (nrow*ncol), sizeof(double));
+  amat=(double **) calloc((unsigned) nrow,sizeof(double*));   
 #endif
     
   for(i=0;i<nrow;i++) amat[i]=avec+i*ncol;
@@ -27,8 +27,8 @@ int **imatrix(int nrow, int ncol)
   avec=(int *)malloc((unsigned) (nrow*ncol)*sizeof(int));
   amat=(int **)malloc((unsigned) nrow*sizeof(int*));
 #else
-  avec=(int *) Calloc((unsigned) (nrow*ncol), int);
-  amat=(int **) Calloc((unsigned) nrow, int*);    
+  avec=(int *) calloc((unsigned) (nrow*ncol), sizeof(int));
+  amat=(int **) calloc((unsigned) nrow, sizeof(int*));    
 #endif
   for(i=0;i<nrow;i++) amat[i]=avec+i*ncol;
   return amat;
@@ -42,9 +42,9 @@ double ***gmatrix(int r, int c, int d)
   amat=(double **)malloc((unsigned) (r*c)*sizeof(double*));
   acube=(double ***)malloc((unsigned) r*sizeof(double**));
 #else
-  avec=(double *) Calloc((unsigned) (r*c*d), double);
-  amat=(double **) Calloc((unsigned) (r*c), double*);
-  acube=(double ***) Calloc((unsigned) r, double**);
+  avec=(double *) calloc((unsigned) (r*c*d), sizeof(double));
+  amat=(double **) calloc((unsigned) (r*c), sizeof(double*));
+  acube=(double ***) calloc((unsigned) r, sizeof(double**));
 #endif
   for(i=0;i<(r*c);i++) amat[i]=avec+i*d;
   for(i=0;i<r;i++) acube[i]=amat+i*c;
